@@ -86,7 +86,7 @@
 #define KEMOTICONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KEMOTICONS_NO_DEPRECATED
-#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
+#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef KEMOTICONS_NO_DEPRECATED_WARNINGS
 #  define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x54800
+#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
